%global __strip %{mingw32_strip}
%global __objdump %{mingw32_objdump}
%define __debug_install_post %{mingw32_debug_install_post}

Name:		mingw-qpid-cpp
Version:	0.14
Release:	3%{?dist}
Summary:	MinGW Windows port of AMQP C++ Daemons and Libraries

Group:		Development/Libraries
License:	ASL 2.0
URL:		http://qpid.apache.org

# first two digits of version
%define release_version %(echo %{version} | awk -F. '{print $1"."$2}')
Source0:        http://www.apache.org/dist/qpid/%{release_version}/qpid-%{version}.tar.gz

# Compatibility with boost 1.48
Patch0:         qpid-cpp-singleton.patch

# Compatibility fixes for mingw-w64
Patch1:         qpid-mingw-w64-compatibility.patch

# Don't automatically try to build the documenation when doxygen is available
Patch2:         qpid-dont-build-docs.patch

# Make sure QMF2 support is enabled
Patch3:         qpid-build-qmf2-on-win32.patch

BuildArch:	noarch

BuildRequires:	redhat-rpm-config cmake make ruby ruby-devel python-devel
BuildRequires:	mingw32-gcc-c++ mingw32-boost mingw32-libxslt mingw32-gnutls
BuildRequires:	mingw32-filesystem

%description
MinGW cross-compiled daemons and run-time libraries for AMQP client
applications developed using Qpid C++. Clients exchange messages with
an AMQP message broker using the AMQP protocol.


%package -n mingw32-qpid-cpp
Summary:	MinGW Windows port of AMQP C++ Daemons and Libraries
Requires:	mingw32-boost mingw32-libxslt mingw32-gnutls

%description -n mingw32-qpid-cpp
MinGW cross-compiled daemons and run-time libraries for AMQP client
applications developed using Qpid C++. Clients exchange messages with
an AMQP message broker using the AMQP protocol.


%{?mingw32_debug_package}

%prep
%setup -q -n qpid-%{version}
%patch0 -p1 -b .singleton
%patch1 -p1 -b .mingw-w64
%patch2 -p1 -b .docs
%patch3 -p2 -b .qmf2

# Temporary ignore various fatal warnings so qpid-cpp can be built against mingw-w64:
# qpid-0.14/cpp/src/qpid/sys/windows/uuid.cpp:54:29: error: cast from type 'const uint8_t* {aka const unsigned char*}' to type 'UUID* {aka _GUID*}' casts away qualifiers [-Werror=cast-qual]
# qpid-0.14/cpp/src/qpid/sys/windows/AsynchIO.cpp:151:12: error: deleting object of polymorphic class type 'qpid::sys::windows::AsynchAcceptResult' which has non-virtual destructor might cause undefined behaviour [-Werror=delete-non-virtual-dtor]
# qpid-0.14/cpp/src/tests/Uuid.cpp:51:167: error: narrowing conversion of ''\37777777672'' from 'char' to 'unsigned char' inside { } is ill-formed in C++11 [-Werror=narrowing]
#
# /usr/i686-w64-mingw32/sys-root/mingw/include/boost/smart_ptr/intrusive_ptr.hpp: In instantiation of 'boost::intrusive_ptr<T>::intrusive_ptr(const boost::intrusive_ptr<T>&) [with T = qpid::sys::TimerTask; boost::intrusive_ptr<T> = boost::intrusive_ptr<qpid::sys::TimerTask>]':
# qpid-0.14/cpp/src/qpid/sys/Timer.cpp:107:52:   required from here
# /usr/i686-w64-mingw32/sys-root/mingw/include/boost/smart_ptr/intrusive_ptr.hpp:91:23: error: 'intrusive_ptr_add_ref' was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation [-fpermissive]
sed -i s/'-Wcast-qual'/'-Wno-error=delete-non-virtual-dtor -Wno-error=narrowing -fpermissive'/ cpp/src/CMakeLists.txt


%build
%{__mkdir_p} build
pushd build
%mingw32_cmake -DCMAKE_BUILD_TYPE=RelWithDebInfo \
		-DBUILD_MSCLFS:BOOL=OFF		  \
		-DBUILD_MSSQL:BOOL=OFF		  \
		-DBUILD_SSL:BOOL=OFF		  \
		-DCMAKE_SHARED_LINKER_FLAGS:STRING=-Wl,--export-all-symbols \
		../cpp
popd

make -C build VERBOSE=1 %{?_smp_mflags}

%install
DESTDIR=$RPM_BUILD_ROOT make -C build VERBOSE=1 install

# Don't package sources in the examples directory
rm -rf $RPM_BUILD_ROOT%{mingw32_prefix}/examples
rm -rf $RPM_BUILD_ROOT%{mingw32_prefix}/bin/qpid-latency-test.exe
rm -rf $RPM_BUILD_ROOT%{mingw32_prefix}/bin/qpid-perftest.exe

# Drop a man-page which is duplicate with the native qpid-cpp package
# and which is installed to the wrong folder anyway
rm -f $RPM_BUILD_ROOT/man1/qpidd.1 || :

# Move the import libraries to the libdir
mkdir $RPM_BUILD_ROOT%{mingw32_libdir}
mv $RPM_BUILD_ROOT%{mingw32_bindir}/*.a $RPM_BUILD_ROOT%{mingw32_libdir}

# Maybe install some test programs for validation
#{__install} -d $RPM_BUILD_ROOT $RPM_BUILD_ROOT{_mingw32_bindir}

%files -n mingw32-qpid-cpp
%doc %{mingw32_prefix}/LICENSE
%doc %{mingw32_prefix}/NOTICE
%doc cpp/RELEASE_NOTES
%{mingw32_prefix}/conf
%dir %{mingw32_prefix}/plugins
%dir %{mingw32_prefix}/plugins/broker
%{mingw32_prefix}/plugins/broker/replicating_listener.dll
%{mingw32_prefix}/plugins/broker/replication_exchange.dll
%{mingw32_prefix}/plugins/broker/store.dll
%{mingw32_prefix}/managementgen
%{mingw32_includedir}/qpid
%{mingw32_includedir}/qmf
%{mingw32_bindir}/qpidd.exe
%{mingw32_bindir}/libqmf.dll
%{mingw32_bindir}/libqmf2.dll
%{mingw32_bindir}/libqmfconsole.dll
%{mingw32_bindir}/libqmfengine.dll
%{mingw32_bindir}/libqpidbroker.dll
%{mingw32_bindir}/libqpidclient.dll
%{mingw32_bindir}/libqpidcommon.dll
%{mingw32_bindir}/libqpidmessaging.dll
%{mingw32_bindir}/libqpidtypes.dll
%{mingw32_libdir}/libqmf.dll.a
%{mingw32_libdir}/libqmf2.dll.a
%{mingw32_libdir}/libqmfconsole.dll.a
%{mingw32_libdir}/libqmfengine.dll.a
%{mingw32_libdir}/libqpidbroker.dll.a
%{mingw32_libdir}/libqpidclient.dll.a
%{mingw32_libdir}/libqpidcommon.dll.a
%{mingw32_libdir}/libqpidmessaging.dll.a
%{mingw32_libdir}/libqpidtypes.dll.a

%changelog
* Thu Mar 08 2012 Erik van Pienbroek <epienbro@fedoraproject.org> - 0.14-3
- Prevent a file conflict with files from the debuginfo package

* Wed Mar 07 2012 Kalev Lember <kalevlember@gmail.com> - 0.14-2
- Renamed the source package to mingw-qpid-cpp (#801018)
- Modernize the spec file
- Use mingw macros without leading underscore

* Sun Feb 26 2012 Erik van Pienbroek <epienbro@fedoraproject.org> - 0.14-1
- Update to 0.14
- Rebuild against the mingw-w64 toolchain
- Made the package compile against mingw-w64
- Fixed boost 1.48 compatibility (thanks to Petr Machata's patch: #761045)
- Dropped upstreamed patch
- Made the Source URL more dynamic
- Dropped the Boost_COMPILER override as that is already
  defined in the mingw32-filesystem package (RHBZ #701334)
- Added -Wl,--export-all-symbols to the linker flags as was done in the RHEL6 package
- Use a more verbose filelist so missing files can be spotted earlier
- Make sure the import libraries are placed in %%{_mingw32_libdir} instead of %%{_mingw32_bindir}

* Mon Jan 16 2012 Ted Ross <tross@apache.org> - 0.12-2.2
- Rebuilt to resolve new dependencies

* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.12-2.1
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Thu Sep 22 2011 Ted Ross <tross@apache.org> - 0.12-1.1
- Rebased to Qpid 0.12

* Wed Jul 5 2011 Ted Ross <tross@apache.org> - 0.10-1.3
- Same patch-set, rebuilt to refresh boost dependencies.

* Wed Jul 5 2011 Ted Ross <tross@apache.org> - 0.10-1.2
- Same patch-set, rebuilt to refresh boost dependencies.

* Wed Jun 22 2011 Ted Ross <tross@apache.org> - 0.10-1.1
- Same patch-set, rebuilt to refresh boost dependencies.

* Fri Apr 29 2011 Ted Ross <tross@apache.org> - 0.10-0.1
- Rebased to Qpid 0.10

* Mon Feb 21 2011 Ted Ross <tross@apache.org> - 0.8-0.6
- Added QMF2 patch from the native qpid-cpp package.

* Tue Feb 15 2011 Ted Ross <tross@apache.org> - 0.8-0.5
- Added definition to force use of boost_filesystem API version 2.

* Mon Feb 14 2011 Andrew Beekhof <andrew@beekhof.net> - 0.8-0.4
- Rebuild for updated boost libraries

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.8-0.3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Tue Dec 21 2010 Andrew Beekhof <andrew@beekhof.net> - 0.8-0.2
- Add dependancy on minw32-filesystem

* Fri Dec 3 2010 Andrew Beekhof <andrew@beekhof.net> - 0.8-0.1
- Update to upstream 0.8-rc3

* Fri Sep 10 2010 Andrew Beekhof <andrew@beekhof.net> - 0.6.895736-1
- Initial package creation
